# OIDCProxyHeaderOverride

This object allows users to control how headers are configured 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**request** | [**OIDCProxyHeaderUserConfig**](OIDCProxyHeaderUserConfig.md) |  | [optional] 
**response** | [**OIDCProxyHeaderUserConfig**](OIDCProxyHeaderUserConfig.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


